mater\_data\_providing.file\_operations
=======================================

.. automodule:: mater_data_providing.file_operations

   
   .. rubric:: Functions

   .. autosummary::
   
      write_json
   